@@ -115,8 +115,10 @@ class LiteralInclude(Directive):
                 line=self.lineno)]
 
         encoding = self.options.get('encoding', env.config.source_encoding)
+        codec_info = codecs.lookup(encoding)
         try:
-            f = codecs.open(fn, 'rU', encoding)
+            f = codecs.StreamReaderWriter(open(fn, 'U'),
+                    codec_info[2], codec_info[3], 'strict')
             lines = f.readlines()
             f.close()
         except (IOError, OSError):
